@@ -30,7 +30,11 @@
 #define _EPHY_DOWNLOAD_H
 
 #include <glib-object.h>
+#ifdef HAVE_WEBKIT2
+#include <webkit2/webkit2.h>
+#else
 #include <webkit/webkit.h>
+#endif
 
 #include "ephy-embed.h"
 
@@ -70,7 +74,8 @@ typedef enum
   EPHY_DOWNLOAD_ACTION_NONE,
   EPHY_DOWNLOAD_ACTION_AUTO,
   EPHY_DOWNLOAD_ACTION_BROWSE_TO,
-  EPHY_DOWNLOAD_ACTION_OPEN
+  EPHY_DOWNLOAD_ACTION_OPEN,
+  EPHY_DOWNLOAD_ACTION_DO_NOTHING
 } EphyDownloadActionType;
 
 GType         ephy_download_get_type              (void) G_GNUC_CONST;
