@@ -18,39 +18,43 @@
  *
  */
 
-#include "config.h"
-
+/* These defines need to go at the top because config.h or ephy-embed-single.h
+ * may include soup.
+ */
 #define LIBSOUP_I_HAVE_READ_BUG_594377_AND_KNOW_SOUP_PASSWORD_MANAGER_MIGHT_GO_AWAY
 #define LIBSOUP_USE_UNSTABLE_REQUEST_API
-#define NSPLUGINWRAPPER_SETUP "/usr/bin/mozilla-plugin-config"
 
+#include "config.h"
 #include "ephy-embed-single.h"
-#include "ephy-embed-shell.h"
-#include "ephy-embed-prefs.h"
-#include "ephy-embed-type-builtins.h"
-#include "ephy-debug.h"
-#include "ephy-file-helpers.h"
-#include "ephy-signal-accumulator.h"
-#include "ephy-permission-manager.h"
-#include "ephy-profile-utils.h"
-#include "ephy-prefs.h"
-#include "ephy-settings.h"
-#include "ephy-request-about.h"
-#include "ephy-about-handler.h"
 
+#include "ephy-about-handler.h"
+#include "ephy-debug.h"
+#include "ephy-embed-prefs.h"
+#include "ephy-embed-shell.h"
+#include "ephy-embed-type-builtins.h"
+#include "ephy-file-helpers.h"
+#include "ephy-permission-manager.h"
+#include "ephy-prefs.h"
+#include "ephy-profile-utils.h"
+#include "ephy-request-about.h"
+#include "ephy-settings.h"
+#include "ephy-signal-accumulator.h"
+
+#include <glib/gi18n.h>
+#include <gnome-keyring.h>
+#include <libsoup/soup-cache.h>
+#include <libsoup/soup-gnome.h>
+#include <libsoup/soup-requester.h>
 #ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
 #else
 #include <webkit/webkit.h>
 #endif
-#include <glib/gi18n.h>
-#include <libsoup/soup-gnome.h>
-#include <libsoup/soup-cache.h>
-#include <libsoup/soup-requester.h>
-#include <gnome-keyring.h>
 
 #define EPHY_EMBED_SINGLE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSinglePrivate))
 
+#define NSPLUGINWRAPPER_SETUP "/usr/bin/mozilla-plugin-config"
+
 struct _EphyEmbedSinglePrivate {
   GHashTable *form_auth_data;
 #ifndef HAVE_WEBKIT2
@@ -58,8 +62,6 @@ struct _EphyEmbedSinglePrivate {
 #endif
 };
 
-static void ephy_embed_single_init (EphyEmbedSingle *single);
-static void ephy_embed_single_class_init (EphyEmbedSingleClass *klass);
 static void ephy_permission_manager_iface_init (EphyPermissionManagerIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (EphyEmbedSingle, ephy_embed_single, G_TYPE_OBJECT,
@@ -109,11 +111,10 @@ get_attr_cb (GnomeKeyringResult result,
       break;
 
     if (attribute[i].type == GNOME_KEYRING_ATTRIBUTE_TYPE_STRING) {
-      if (g_str_equal (attribute[i].name, "server")) {
+      if (g_str_equal (attribute[i].name, "server"))
         server = g_strdup (attribute[i].value.string);
-      } else if (g_str_equal (attribute[i].name, "user")) {
+      else if (g_str_equal (attribute[i].name, "user"))
         username = g_strdup (attribute[i].value.string);
-      }
     }
   }
 
@@ -417,7 +418,6 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   char *cookie_policy;
 
   /* TODO: SoupCache, SSL, favicons */
-
   web_context = webkit_web_context_get_default ();
 
   /* Store cookies in moz-compatible SQLite format */
@@ -436,7 +436,7 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   webkit_web_context_register_uri_scheme (web_context,
                                           EPHY_ABOUT_SCHEME,
                                           about_request_cb,
-                                          NULL);
+                                          NULL, NULL);
 #else
   SoupSession *session;
   SoupCookieJar *jar;
@@ -446,6 +446,7 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   char *favicon_db_path;
   EphyEmbedSinglePrivate *priv = single->priv;
   SoupSessionFeature *requester;
+  EphyEmbedShellMode mode;
 
   /* Initialise nspluginwrapper's plugins if available */
   if (g_file_test (NSPLUGINWRAPPER_SETUP, G_FILE_TEST_EXISTS) != FALSE)
@@ -474,8 +475,12 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   /* Use GNOME proxy settings through libproxy */
   soup_session_add_feature_by_type (session, SOUP_TYPE_PROXY_RESOLVER_GNOME);
 
+  mode = ephy_embed_shell_get_mode (ephy_embed_shell_get_default ());
+
   /* WebKitSoupCache */
-  cache_dir = g_build_filename (g_get_user_cache_dir (), g_get_prgname (), NULL);
+  cache_dir = g_build_filename (mode == EPHY_EMBED_SHELL_MODE_PRIVATE ?
+                                ephy_dot_dir () : g_get_user_cache_dir (),
+                                g_get_prgname (), NULL);
   priv->cache = soup_cache_new (cache_dir, SOUP_CACHE_SINGLE_USER);
   g_free (cache_dir);
 
@@ -495,12 +500,12 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   soup_session_feature_add_feature (requester, EPHY_TYPE_REQUEST_ABOUT);
   g_object_unref (requester);
 
-#ifdef SOUP_TYPE_PASSWORD_MANAGER
+#ifdef SOUP_TYPE_PASSWORD_MANAGER_GNOME
   /* Use GNOME keyring to store passwords. Only add the manager if we
      are not using a private session, otherwise we want any new
      password to expire when we exit *and* we don't want to use any
      existing password in the keyring */
-  if (ephy_embed_shell_get_mode (ephy_embed_shell_get_default ()) != EPHY_EMBED_SHELL_MODE_PRIVATE)
+  if (mode != EPHY_EMBED_SHELL_MODE_PRIVATE)
     soup_session_add_feature_by_type (session, SOUP_TYPE_PASSWORD_MANAGER_GNOME);
 #endif
 
