@@ -26,13 +26,13 @@
 #define FORM_USERNAME_KEY "form_username"
 #define FORM_PASSWORD_KEY "form_password"
 
-#define EPHY_PROFILE_MIGRATION_VERSION 7
+#define EPHY_PROFILE_MIGRATION_VERSION 8
 
 int ephy_profile_utils_get_migration_version (void);
 
 gboolean ephy_profile_utils_set_migration_version (int version);
 
-gboolean ephy_profile_utils_do_migration (int test_to_run, gboolean debug);
+gboolean ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run, gboolean debug);
 
 void _ephy_profile_utils_store_form_auth_data (const char *uri,
                                                const char *form_username,
