@@ -33,6 +33,7 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
+#include <libsoup/soup.h>
 #include <string.h>
 
 #define HTML_STRING "testing-ephy-download"
@@ -166,7 +167,9 @@ main (int argc, char *argv[])
   ephy_embed_prefs_init ();
   _ephy_shell_create_instance (EPHY_EMBED_SHELL_MODE_PRIVATE);
 
-  if (!ephy_file_helpers_init (NULL, TRUE, FALSE, NULL)) {
+  if (!ephy_file_helpers_init (NULL,
+                               EPHY_FILE_HELPERS_PRIVATE_PROFILE | EPHY_FILE_HELPERS_ENSURE_EXISTS,
+                               NULL)) {
     g_debug ("Something wrong happened with ephy_file_helpers_init()");
     return -1;
   }
